@@ -27,7 +27,7 @@ class TestCli(unittest.TestCase):
     def test_cron(self):
 
         output = check_output('{} cron_on'.format(cmd), shell=True)
-        self.assertTrue("\"enabled\"" in output)
+        self.assertTrue("\"enabled\"" in output, output)
         output = check_output('{} cron_on'.format(cmd), shell=True)
         self.assertTrue("\"already enabled\"" in output)
 
